@@ -5,7 +5,6 @@ import hashlib
 import logging
 from typing import Any, Collection, Dict, Iterable, Mapping, Optional, Sequence, Tuple, Union
 
-from pytype import compat
 from pytype import datatypes
 from pytype import utils
 from pytype.pyc import opcodes
@@ -209,6 +208,8 @@ def get_signatures(func):
     return [sig.drop_first_parameter() for sig in sigs]  # drop "self"
   elif func.isinstance_ClassMethod() or func.isinstance_StaticMethod():
     return get_signatures(func.method)
+  elif func.isinstance_SimpleFunction():
+    return [func.signature]
   else:
     raise NotImplementedError(func.__class__.__name__)
 
@@ -514,7 +515,7 @@ def _hash_dict(vardict, names):
     vardict = {name: vardict[name] for name in names.intersection(vardict)}
   m = hashlib.md5()
   for name, var in sorted(vardict.items()):
-    m.update(compat.bytestring(name))
+    m.update(str(name).encode("utf-8"))
     for value in var.bindings:
       m.update(value.data.get_fullhash())
   return m.digest()
@@ -844,3 +845,65 @@ def combine_substs(
     return substs2
   else:
     return ()
+
+
+def _flatten(value, classes):
+  """Flatten the contents of value into classes.
+
+  If value is a Class, it is appended to classes.
+  If value is a PythonConstant of type tuple, then each element of the tuple
+  that has a single binding is also flattened.
+  Any other type of value, or tuple elements that have multiple bindings are
+  ignored.
+
+  Args:
+    value: An abstract value.
+    classes: A list to be modified.
+
+  Returns:
+    True iff a value was ignored during flattening.
+  """
+  # Used by special_builtins.IsInstance and IsSubclass
+  if value.isinstance_AnnotationClass():
+    value = value.base_cls
+  if value.isinstance_Class():
+    # A single class, no ambiguity.
+    classes.append(value)
+    return False
+  elif value.isinstance_Tuple():
+    # A tuple, need to process each element.
+    ambiguous = False
+    for var in value.pyval:
+      if (len(var.bindings) != 1 or
+          _flatten(var.bindings[0].data, classes)):
+        # There were either multiple bindings or ambiguity deeper in the
+        # recursion.
+        ambiguous = True
+    return ambiguous
+  else:
+    return True
+
+
+def check_against_mro(vm, target, class_spec):
+  """Check if any of the classes are in the target's MRO.
+
+  Args:
+    vm: The virtual machine.
+    target: A BaseValue whose MRO will be checked.
+    class_spec: A Class or PythonConstant tuple of classes (i.e. the second
+      argument to isinstance or issubclass).
+
+  Returns:
+    True if any class in classes is found in the target's MRO,
+    False if no match is found and None if it's ambiguous.
+  """
+  # Determine the flattened list of classes to check.
+  classes = []
+  ambiguous = _flatten(class_spec, classes)
+
+  for c in classes:
+    if vm.matcher(None).match_from_mro(target, c, allow_compat_builtins=False):
+      return True  # A definite match.
+  # No matches, return result depends on whether flatten() was
+  # ambiguous.
+  return None if ambiguous else False
