@@ -121,7 +121,7 @@ class Class(metaclass=mixin.MixinMeta):
     self._all_formal_type_parameters_loaded = False
     # Call these methods in addition to __init__ when constructing instances.
     self.additional_init_methods = []
-    if self._is_test_class():
+    if self.is_test_class():
       self.additional_init_methods.append("setUp")
 
   def bases(self):
@@ -173,10 +173,18 @@ class Class(metaclass=mixin.MixinMeta):
       self.protocol_attributes = set()
       return
     if self.isinstance_PyTDClass() and self.pytd_cls.name.startswith("typing."):
+      protocol_attributes = set()
+      if self.pytd_cls.name == "typing.Mapping":
+        # Append Mapping-specific attributes to forbid matching against classes
+        # that satisfy the Mapping ABC but don't contain mapping_attrs.
+        mapping_attrs = {"__contains__", "keys", "items", "values", "get",
+                         "__eq__", "__ne__"}
+        protocol_attributes |= mapping_attrs
       # In typing.pytd, we've experimentally marked some classes such as
       # Sequence, which contains a mix of abstract and non-abstract methods, as
       # protocols, with only the abstract methods being required.
-      self.protocol_attributes = self.abstract_methods
+      protocol_attributes |= self.abstract_methods
+      self.protocol_attributes = protocol_attributes
       return
     # For the algorithm to run, protocol_attributes needs to be populated with
     # the protocol attributes defined by this class. We'll overwrite the
@@ -197,15 +205,14 @@ class Class(metaclass=mixin.MixinMeta):
   def _init_overrides_bool(self):
     """Compute and cache whether the class sets its own boolean value."""
     # A class's instances can evaluate to False if it defines __bool__ or
-    # __len__. Python2 used __nonzero__ rather than __bool__.
-    bool_override = "__bool__" if self.vm.PY3 else "__nonzero__"
+    # __len__.
     if self.isinstance_ParameterizedClass():
       self.overrides_bool = self.base_cls.overrides_bool
       return
     for cls in self.mro:
       if isinstance(cls, Class):
         if any(x in cls.get_own_attributes()
-               for x in (bool_override, "__len__")):
+               for x in ("__bool__", "__len__")):
           self.overrides_bool = True
           return
     self.overrides_bool = False
@@ -255,7 +262,7 @@ class Class(metaclass=mixin.MixinMeta):
     return ((self._has_explicit_abcmeta() or self._has_implicit_abcmeta()) and
             bool(self.abstract_methods))
 
-  def _is_test_class(self):
+  def is_test_class(self):
     return any(base.full_name in ("unittest.TestCase", "unittest.case.TestCase")
                for base in self.mro)
 
@@ -462,9 +469,17 @@ class Class(metaclass=mixin.MixinMeta):
       return self._get_mro_attrs_for_attrs(cls_attrs, metadata_key)
 
     all_attrs = {}
-    sub_attrs = [base_cls.metadata.get(metadata_key, [])
-                 for base_cls in reversed(self.mro[1:])
-                 if isinstance(base_cls, Class)]
+    sub_attrs = []
+    attributes_to_ignore = set()
+    for base_cls in reversed(self.mro[1:]):
+      if not isinstance(base_cls, Class):
+        continue
+      # Some third-party dataclass implementations add implicit fields that
+      # should not be considered inherited attributes.
+      attributes_to_ignore.update(getattr(base_cls, "IMPLICIT_FIELDS", ()))
+      if metadata_key in base_cls.metadata:
+        sub_attrs.append([a for a in base_cls.metadata[metadata_key]
+                          if a.name not in attributes_to_ignore])
     sub_attrs.append(cls_attrs)
     for attrs in sub_attrs:
       for a in attrs:
