@@ -45,13 +45,16 @@ MAX_VAR_SIZE = 64
 #    elements: A list or map of top-level types
 #    value: The concrete python value
 #
-#  'elements' is an intermediate structure that tracks individual typestructs
-#  for every element in a map or list. So e.g. for the constant
+#  'elements' is an intermediate structure that tracks individual folded
+#  constants for every element in a map or list. So e.g. for the constant
 #    {'x': [1, 2], 'y': 3}
 #  we would have
 #    typ = ('map', {str}, {('list', {int}), int})
 #    value = {'x': [1, 2], 'y': 3}
-#    elements = {'x': ('list', {int}), 'y': int}
+#    elements = {'x': <<[1, 2]>>, 'y': <<3>>}
+#  where <<x>> is the folded constant corresponding to x. This lets us
+#  short-circuit pyval tracking at any level in the structure and fall back to
+#  abstract types.
 #
 #  Note that while we could in theory just track the python value, and then
 #  construct 'typ' and 'elements' at the end, that would mean recursively
@@ -98,7 +101,7 @@ class _CollectionBuilder:
 
   def add(self, constant):
     self.types.add(constant.typ)
-    self.elements.append(constant.typ)
+    self.elements.append(constant)
     self.values.append(constant.value)
 
   def build(self):
@@ -123,7 +126,7 @@ class _MapBuilder:
     self.value_types.add(value.typ)
     self.keys.append(key.value)
     self.values.append(value.value)
-    self.elements[key.value] = value.typ
+    self.elements[key.value] = value
 
   def build(self):
     return _Map(
@@ -150,42 +153,73 @@ class _Stack:
   def pop(self):
     return self.stack.pop()
 
+  def _preserve_constant(self, c):
+    if c and (
+        not isinstance(c.op, opcodes.LOAD_CONST) or
+        isinstance(c.op, opcodes.BUILD_STRING)):
+      self.consts[id(c.op)] = c
+
   def clear(self):
     # Preserve any constants in the stack before clearing it.
     for c in self.stack:
-      if (not isinstance(c.op, opcodes.LOAD_CONST) or
-          isinstance(c.op, opcodes.BUILD_STRING)):
-        self.consts[id(c.op)] = c
+      self._preserve_constant(c)
     self.stack = []
 
+  def _pop_args(self, n):
+    """Try to get n args off the stack for a BUILD call."""
+    # TODO(b/175443170): Handle the case of n = 0 - we currently back out of
+    # folding a constant that contains an empty list/map/fstring as an element.
+    if len(self.stack) < n:
+      # We have started a new block in the middle of constructing a literal
+      # (e.g. due to an inline function call). Clear the stack, since the
+      # literal is not constant.
+      self.clear()
+      return None
+    elif any(x is None for x in self.stack[-n:]):
+      # We have something other than constants in the arg list. Pop all the args
+      # for this op off the stack, preserving constants.
+      for _ in range(n):
+        self._preserve_constant(self.pop())
+      return None
+    else:
+      return [self.pop() for _ in range(n)]
+
   def fold_args(self, n, op):
     """Collect the arguments to a build call."""
     ret = _CollectionBuilder()
-    if len(self.stack) < n:
-      # We have something other than constants in the op list
+    args = self._pop_args(n)
+    if not args:
+      self.push(None)
       return None
-    else:
-      for _ in range(n):
-        elt = self.pop()
-        ret.add(elt)
-        elt.op.folded = op
+
+    for elt in args:
+      ret.add(elt)
+      elt.op.folded = op
     return ret.build()
 
   def fold_map_args(self, n, op):
     """Collect the arguments to a BUILD_MAP call."""
     ret = _MapBuilder()
-    if len(self.stack) < 2 * n:
-      # We have something other than constants in the op list
+    args = self._pop_args(2 * n)
+    if not args:
+      self.push(None)
       return None
-    else:
-      for _ in range(n):
-        v_elt = self.pop()
-        k_elt = self.pop()
-        ret.add(k_elt, v_elt)
-        k_elt.op.folded = op
-        v_elt.op.folded = op
+
+    for i in range(0, 2 * n, 2):
+      v_elt, k_elt = args[i], args[i + 1]
+      ret.add(k_elt, v_elt)
+      k_elt.op.folded = op
+      v_elt.op.folded = op
     return ret.build()
 
+  def build_str(self, n, op):
+    ret = self.fold_args(n, op)
+    if ret:
+      self.push(_Constant(('prim', str), '', None, op))
+    else:
+      self.push(None)
+    return ret
+
   def build(self, python_type, op):
     collection = self.fold_args(op.arg, op)
     if collection:
@@ -244,12 +278,11 @@ class _FoldConstants:
           stack.build(set, op)
         elif isinstance(op, opcodes.FORMAT_VALUE):
           if op.arg & loadmarshal.FVS_MASK:
-            stack.pop()
-          _ = stack.fold_args(1, op)
-          stack.push(_Constant(('prim', str), '', None, op))
+            stack.build_str(2, op)
+          else:
+            stack.build_str(1, op)
         elif isinstance(op, opcodes.BUILD_STRING):
-          _ = stack.fold_args(op.arg, op)
-          stack.push(_Constant(('prim', str), '', None, op))
+          stack.build_str(op.arg, op)
         elif isinstance(op, opcodes.BUILD_MAP):
           map_ = stack.fold_map_args(op.arg, op)
           if map_:
@@ -268,9 +301,10 @@ class _FoldConstants:
             stack.push(_Constant(typ, val, elements, op))
         else:
           # If we hit any other bytecode, we are no longer building a literal
-          # constant. Clear the stack, but save any substructures that have
-          # already been folded from primitives.
-          stack.clear()
+          # constant. Insert a None as a sentinel to the next BUILD op to
+          # not fold itself.
+          stack.push(None)
+
       # Clear the stack to save any folded constants before exiting the block
       stack.clear()
 
@@ -284,6 +318,8 @@ class _FoldConstants:
           pretty_arg = t
           o = opcodes.LOAD_FOLDED_CONST(op.index, op.line, arg, pretty_arg)
           o.next = op.next
+          o.target = op.target
+          o.block_target = op.block_target
           op.folded = o
           folds.add(op)
           out.append(o)
@@ -370,52 +406,69 @@ def build_folded_type(vm, state, const):
     """Create a constant purely to hold types for a recursive call."""
     return _Constant(t, None, None, const.op)
 
-  def build_pyval(state, typ, pyval):
-    if pyval and typ[0] in ('prim', 'tuple'):
-      return state, vm.convert.constant_to_var(pyval)
+  def build_pyval(state, const):
+    if const.value is not None and const.tag in ('prim', 'tuple'):
+      return state, vm.convert.constant_to_var(const.value)
     else:
-      return build_folded_type(vm, state, typeconst(typ))
+      return build_folded_type(vm, state, const)
 
-  def expand(state, types, pyvals):
+  def expand(state, elements):
     vs = []
-    pyvals = pyvals or [None for _ in types]
-    for t, p in zip(types, pyvals):
-      state, v = build_pyval(state, t, p)
+    for e in elements:
+      state, v = build_pyval(state, e)
       vs.append(v)
     return state, vs
 
-  def join(state, xs):
-    state, vs = expand(state, xs, None)
+  def join_types(state, ts):
+    xs = [typeconst(t) for t in ts]
+    state, vs = expand(state, xs)
     val = vm.convert.build_content(vs)
     return state, val
 
   def collect(state, convert_type, params):
-    state, t = join(state, params)
+    state, t = join_types(state, params)
     ret = vm.convert.build_collection_of_type(state.node, convert_type, t)
     return state, ret
 
-  def collect_tuple(state, params, pyvals):
-    state, vs = expand(state, params, pyvals)
+  def collect_tuple(state, elements):
+    state, vs = expand(state, elements)
     return state, vm.convert.build_tuple(state.node, vs)
 
-  def collect_list(state, params, elements, pyvals):
-    if elements is not None and len(elements) < MAX_VAR_SIZE:
-      state, vs = expand(state, elements, pyvals)
+  def collect_list(state, params, elements):
+    if elements is None:
+      return collect(state, vm.convert.list_type, params)
+    elif len(elements) < MAX_VAR_SIZE:
+      state, vs = expand(state, elements)
       return state, vm.convert.build_list(state.node, vs)
     else:
-      return collect(state, vm.convert.list_type, params)
+      # Without constant folding we construct a variable wrapping every element
+      # in the list and store it; however, we cannot retrieve them all. So as an
+      # optimisation, we will add the first few elements as pyals, then add one
+      # element for every contained type, and rely on the fact that the tail
+      # elements will contribute to the overall list type, but will not be
+      # retrievable as pyvals.
+      # TODO(b/175443170): We should use a smaller MAX_SUBSCRIPT cutoff; this
+      # behaviour is unrelated to MAX_VAR_SIZE (which limits the number of
+      # distinct bindings for the overall typevar).
+      elts = elements[:MAX_VAR_SIZE] + tuple(typeconst(t) for t in params)
+      state, vs = expand(state, elts)
+      return state, vm.convert.build_list(state.node, vs)
 
-  def collect_map(state, params, elements, pyvals):
+  def collect_map(state, params, elements):
     m = vm.convert.build_map(state.node)
     if elements is not None and len(elements) < MAX_VAR_SIZE:
-      pyvals = pyvals or [None for _ in elements]
-      for (k, v), p in zip(elements.items(), pyvals):
+      for (k, v) in elements.items():
         k = vm.convert.constant_to_var(k)
-        state, v = build_pyval(state, v, p)
+        state, v = build_pyval(state, v)
         state = vm.store_subscr(state, m, k, v)
     else:
+      # Treat a too-large dictionary as {Union[keys] : Union[vals]}. We could
+      # store a subset of the k/v pairs, as with collect_list, but for
+      # dictionaries it is less obvious which subset we should be storing.
+      # Perhaps we could create one variable per unique value type, and then
+      # store every key in the pyval but reuse the value variables.
       k_types, v_types = params
-      state, v = join(state, v_types)
+      state, v = join_types(state, v_types)
       for t in k_types:
         state, k = build_folded_type(vm, state, typeconst(t))
         state = vm.store_subscr(state, m, k, v)
@@ -429,13 +482,18 @@ def build_folded_type(vm, state, const):
       val = vm.convert.primitive_class_instances[params]
       return state, val.to_variable(state.node)
   elif tag == 'list':
-    return collect_list(state, params, const.elements, const.value)
+    return collect_list(state, params, const.elements)
   elif tag == 'set':
     return collect(state, vm.convert.set_type, params)
   elif tag == 'tuple':
-    return collect_tuple(state, params, const.value)
+    # If we get a tuple without const.elements, construct it from the type.
+    # (e.g. this happens with a large dict with tuple keys)
+    if not const.elements:
+      elts = tuple(typeconst(t) for t in params)
+    else:
+      elts = const.elements
+    return collect_tuple(state, elts)
   elif tag == 'map':
-    pyvals = const.value and const.value.values()
-    return collect_map(state, params, const.elements, pyvals)
+    return collect_map(state, params, const.elements)
   else:
     assert False, ('Unexpected type tag:', const.typ)
