@@ -30,9 +30,9 @@ def show_op(op):
   typ = literal(op.arg.typ)
   elements = op.arg.elements
   if isinstance(elements, dict):
-    elements = {k: literal(v) for k, v in elements.items()}
+    elements = {k: literal(v.typ) for k, v in elements.items()}
   elif elements:
-    elements = [literal(v) for v in elements]
+    elements = [literal(v.typ) for v in elements]
   return (op.line, typ, op.arg.value, elements)
 
 
@@ -176,6 +176,46 @@ class TestFolding(test_base.UnitTest):
         (4, ("list", map_type), val, [map_type, map_type])
     ])
 
+  def test_nested_partial(self):
+    # Test that partial expressions get cleaned off the stack properly. The 'if'
+    # is there to introduce block boundaries.
+    actual = self._process("""
+      v = None
+      x = {
+         [{'a': 'c', 'b': v}],
+         [{'a': 'd', 'b': v}]
+      }
+      if __random__:
+        y = [{'value': v, 'type': 'a'}]
+      else:
+        y = [{'value': v, 'type': 'b'}]
+    """)
+    self.assertCountEqual(actual, [])
+
+  def test_function_call(self):
+    actual = self._process("""
+      a = {
+          'name': 'x'.isascii(),
+          'type': 'package',
+          'foo': sorted(set())
+      }
+    """)
+    self.assertCountEqual(actual, [])
+
+  def test_fstring(self):
+    actual = self._process("""
+      x = 'hello'
+      y = set(1, 2, 3)
+      a = f'foo{x}{y}'  # Not folded
+      b = f'foo{0:08}'  # Folded
+      c = f'foo{x:<9}'  # Not folded
+      d = f'foo{x:}'  # Not folded
+      e = f'foo{x:0{8}x}'  # Internal subsection '0{8}x' folded
+      f = f'{x:05}.a'  # Not folded
+      g = f'pre.{x:05}.post'  # Not folded
+    """)
+    self.assertCountEqual(actual, [(4, str, "", None), (7, str, "", None)])
+
 
 class TypeBuilderTestBase(test_base.UnitTest):
   """Base class for constructing and testing vm types."""
@@ -246,9 +286,6 @@ class PyvalTest(TypeBuilderTestBase):
     _, defs = self.vm.run_program(src, "", maximum_depth=4)
     return defs
 
-  def assertNoPyval(self, val):
-    self.assertFalse(hasattr(val, "pyval"))
-
   def test_simple_list(self):
     defs = self._process("""
       a = [1, '2', 3]
@@ -260,7 +297,6 @@ class PyvalTest(TypeBuilderTestBase):
     self.assertPytd(b, "str")
     self.assertEqual(a.pyval[0].data[0].pyval, 1)
 
-  @test_utils.skipFromPy((3, 9), "assertNoPyval check fails in 3.9")
   def test_nested_list(self):
     defs = self._process("""
       a = [[1, '2', 3], [4, 5]]
@@ -274,17 +310,38 @@ class PyvalTest(TypeBuilderTestBase):
     self.assertPytd(a, f"List[Union[{t2}, {t1}]]")
     self.assertPytd(b, t1)
     self.assertPytd(c, t2)
-    self.assertNoPyval(a.pyval[0].data[0])
 
   def test_long_list(self):
     elts = ["  [1, 2],", "  ['a'],"] * 42
     src = ["a = ["] + elts + ["]"]
+    src += ["b = a[0]", "c = a[1]", "d = [a[72]]"]
     defs = self._process("\n".join(src))
     a = defs["a"].data[0]
+    b = defs["b"].data[0]
+    c = defs["c"].data[0]
+    d = defs["d"].data[0]
     t1 = "List[int]"
     t2 = "List[str]"
+    self.assertPytd(a, "List[Any]")
+    self.assertPytd(b, t1)
+    self.assertPytd(c, t2)
+    self.assertPytd(d, "List[Any]")
+
+  def test_long_list_of_tuples(self):
+    elts = ["  (1, 2),", "  ('a', False),"] * 82
+    src = ["a = ["] + elts + ["]"]
+    src += ["b = a[0]", "c = a[1]", "d = [a[72]]"]
+    defs = self._process("\n".join(src))
+    a = defs["a"].data[0]
+    b = defs["b"].data[0]
+    c = defs["c"].data[0]
+    d = defs["d"].data[0]
+    t1 = "Tuple[int, int]"
+    t2 = "Tuple[str, bool]"
     self.assertPytd(a, f"List[Union[{t1}, {t2}]]")
-    self.assertNoPyval(a)
+    self.assertPytd(b, t1)
+    self.assertPytd(c, t2)
+    self.assertPytd(d, f"List[Union[{t1}, {t2}]]")
 
   def test_simple_map(self):
     defs = self._process("""
@@ -300,24 +357,46 @@ class PyvalTest(TypeBuilderTestBase):
     self.assertPytd(c, "str")
     self.assertEqual(a.pyval["b"].data[0].pyval, 1)
 
-  @test_utils.skipFromPy((3, 9), "assertNoPyval check fails in 3.9")
+  def test_boolean(self):
+    defs = self._process("""
+      a = {'b': False, 'c': True, 'd': None}
+    """)
+    a = defs["a"].data[0]
+    # pylint: disable=g-generic-assert
+    self.assertEqual(a.pyval["b"].data[0].pyval, False)
+    self.assertEqual(a.pyval["c"].data[0].pyval, True)
+    self.assertEqual(a.pyval["d"].data[0].pyval, None)
+    # pylint: enable=g-generic-assert
+
   def test_nested_map(self):
     defs = self._process("""
-      a = {'b': [1, '2', 3], 'c': {'x': 4}}
+      a = {'b': [1, '2', 3], 'c': {'x': 4, 'y': True}}
       b = a['b']
       c = a['c']
+      d = a['c']['x']
     """)
     a = defs["a"].data[0]
     b = defs["b"].data[0]
     c = defs["c"].data[0]
+    d = defs["d"].data[0]
     t1 = "List[Union[int, str]]"
-    t2 = "Dict[str, int]"
+    t2 = "Dict[str, Union[bool, int]]"
     self.assertPytd(a, f"Dict[str, Union[{t2}, {t1}]]")
     self.assertPytd(b, t1)
     self.assertPytd(c, t2)
-    self.assertNoPyval(a.pyval["b"].data[0])
-    # We create an empty pyval by default for abstract.Dict
-    self.assertFalse(a.pyval["c"].data[0].pyval)
+    self.assertPytd(d, "int")
+    # Check the shape of the nested pyvals (their contents need to be unpacked
+    # from variables).
+    self.assertEqual(len(a.pyval["b"].data[0].pyval), 3)
+    self.assertEqual(list(a.pyval["c"].data[0].pyval.keys()), ["x", "y"])
+
+  def test_deep_nesting(self):
+    defs = self._process("""
+      a = {'b': [1, {'c': 1, 'd': {'x': 4, 'y': ({'p': 4, q: 3}, 1)}}]}
+      b = a['b'][1]['d']['y'][0]['p']
+    """)
+    b = defs["b"].data[0]
+    self.assertPytd(b, "int")
 
   def test_long_map(self):
     elts = [f"  'k{i}': [1, 2]," for i in range(64)]
@@ -325,8 +404,34 @@ class PyvalTest(TypeBuilderTestBase):
     defs = self._process("\n".join(src))
     a = defs["a"].data[0]
     self.assertPytd(a, "Dict[str, List[int]]")
+
+  def test_long_map_with_tuple_keys(self):
+    elts = [f"  ({i}, True): 'a'," for i in range(64)]
+    src = ["a = {"] + elts + ["}"]
+    defs = self._process("\n".join(src))
+    a = defs["a"].data[0]
+    self.assertPytd(a, "Dict[Tuple[int, bool], str]")
     self.assertFalse(a.pyval)
 
+  def test_nested_long_map(self):
+    # Elements in the long map should be collapsed to a single type.
+    # Elements not in the long map should have pyvals (specifically, the
+    # container with the long map in it should not be collapsed).
+    elts = [f"  'k{i}': [1, True]," for i in range(64)]
+    src = ["x = [1, {"] + elts + ["}, {'x': 2}]"]
+    src += ["a = x[0]", "b = x[1]", "c = x[2]"]
+    src += ["d = c['x']", "e = [b['random'][1]]"]
+    defs = self._process("\n".join(src))
+    a = defs["a"].data[0]
+    b = defs["b"].data[0]
+    c = defs["c"].data[0]
+    d = defs["d"].data[0]
+    e = defs["e"].data[0]
+    self.assertPytd(a, "int")
+    self.assertPytd(b, "Dict[str, List[Union[bool, int]]]")
+    self.assertPytd(c, "Dict[str, int]")
+    self.assertPytd(d, "int")
+    self.assertPytd(e, "List[Union[bool, int]]")
 
 if __name__ == "__main__":
   unittest.main()
