@@ -3,6 +3,7 @@
 import collections
 import contextlib
 import csv
+import io
 import logging
 import re
 import sys
@@ -20,7 +21,6 @@ from pytype.pytd import optimize
 from pytype.pytd import pytd_utils
 from pytype.pytd import slots
 from pytype.pytd import visitors
-import six
 
 # Usually we call the logger "log" but that name is used quite often here.
 _log = logging.getLogger(__name__)
@@ -460,9 +460,9 @@ class ErrorLogBase:
     self.print_to_file(sys.stderr)
 
   def __str__(self):
-    io = six.StringIO()
-    self.print_to_file(io)
-    return io.getvalue()
+    f = io.StringIO()
+    self.print_to_file(f)
+    return f.getvalue()
 
 
 class ErrorLog(ErrorLogBase):
@@ -536,7 +536,7 @@ class ErrorLog(ErrorLogBase):
       output_mode = convert.OutputMode.DETAILED
     with convert.set_output_mode(output_mode):
       bad_actual = self._pytd_print(pytd_utils.JoinTypes(
-          view[actual].data.to_type(node, view=view) for view, _ in bad))
+          view[actual].data.to_type(node, view=view) for view, _, _ in bad))
       if len(actual.bindings) > len(bad):
         full_actual = self._pytd_print(pytd_utils.JoinTypes(
             v.to_type(node) for v in actual.data))
@@ -544,9 +544,15 @@ class ErrorLog(ErrorLogBase):
         full_actual = bad_actual
     # typing.NoReturn is a prettier alias for nothing.
     fmt = lambda ret: "NoReturn" if ret == "nothing" else ret
-    protocol_details = sorted(set("\n" + self._print_protocol_error(e)
-                                  for _, e in bad if e))
-    return fmt(expected), fmt(bad_actual), fmt(full_actual), protocol_details
+    protocol_details, nis_details = self._prepare_errorlog_details(bad)
+    return (fmt(expected), fmt(bad_actual), fmt(full_actual), protocol_details,
+            nis_details)
+
+  def _print_as_function_def(self, fn):
+    assert fn.isinstance_Function()
+    conv = fn.vm.convert.pytd_convert
+    name = fn.name.rsplit(".", 1)[-1]  # We want `def bar()` not `def Foo.bar()`
+    return pytd_utils.Print(conv.value_to_pytd_def(fn.vm.root_node, fn, name))
 
   def _print_protocol_error(self, error):
     """Pretty-print the matcher.ProtocolError instance."""
@@ -558,10 +564,38 @@ class ErrorLog(ErrorLogBase):
               f"{left}: {missing}")
     else:
       assert isinstance(error, matcher.ProtocolTypeError)
-      actual = self._pytd_print(error.actual_type.to_type())
-      expected = self._pytd_print(error.expected_type.to_type())
-      return (f"Attribute {error.attribute_name} of protocol {protocol} has "
-              f"wrong type in {left}: expected {expected}, got {actual}")
+      actual, expected = error.actual_type, error.expected_type
+      if (actual.isinstance_Function() and expected.isinstance_Function()):
+        # TODO(b/196434939): When matching a protocol like Sequence[int] the
+        # protocol name will be Sequence[int] but the method signatures will be
+        # displayed as f(self: Sequence[_T], ...).
+        actual = self._print_as_function_def(actual)
+        expected = self._print_as_function_def(expected)
+        return (f"\nMethod {error.attribute_name} of protocol {protocol} has "
+                f"the wrong signature in {left}:\n\n"
+                f">> {protocol} expects:\n{expected}\n\n"
+                f">> {left} defines:\n{actual}")
+      else:
+        actual = self._pytd_print(error.actual_type.to_type())
+        expected = self._pytd_print(error.expected_type.to_type())
+        return (f"Attribute {error.attribute_name} of protocol {protocol} has "
+                f"wrong type in {left}: expected {expected}, got {actual}")
+
+  def _print_noniterable_str_error(self, error):
+    return (
+        f"Note: {error.left_type.name} does not match iterables by default. "
+        "Learn more: https://github.com/google/pytype/blob/master/docs/faq.md#why-doesnt-str-match-against-string-iterables")
+
+  def _prepare_errorlog_details(self, bad):
+    protocol_details = set()
+    nis_details = set()
+    for _, protocol_err, nis_err in bad:
+      if protocol_err:
+        protocol_details.add("\n" + self._print_protocol_error(protocol_err))
+      if nis_err:
+        nis_details.add("\n" + self._print_noniterable_str_error(nis_err))
+
+    return sorted(protocol_details), sorted(nis_details)
 
   def _join_printed_types(self, types):
     """Pretty-print the union of the printed types."""
@@ -711,6 +745,9 @@ class ErrorLog(ErrorLogBase):
         ")"])
     if bad_param and bad_param.protocol_error:
       details += "\n" + self._print_protocol_error(bad_param.protocol_error)
+    if bad_param and bad_param.noniterable_str_error:
+      details += "\n" + self._print_noniterable_str_error(
+          bad_param.noniterable_str_error)
     self.error(stack, message, details, bad_call=bad_call)
 
   @_error_name("wrong-arg-count")
@@ -861,7 +898,7 @@ class ErrorLog(ErrorLogBase):
   @_error_name("bad-return-type")
   def bad_return_type(self, stack, node, formal, actual, bad):
     """Logs a [bad-return-type] error."""
-    expected, bad_actual, full_actual, protocol_details = (
+    expected, bad_actual, full_actual, protocol_details, nis_details = (
         self._print_as_return_types(node, formal, actual, bad))
     if full_actual == bad_actual:
       message = "bad return type"
@@ -869,24 +906,46 @@ class ErrorLog(ErrorLogBase):
       message = f"bad option {bad_actual!r} in return type"
     details = ["         Expected: ", expected, "\n",
                "Actually returned: ", full_actual]
-    details.extend(protocol_details)
+    details.extend(protocol_details + nis_details)
     self.error(stack, message, "".join(details))
 
+  @_error_name("bad-yield-annotation")
+  def bad_yield_annotation(self, stack, name, annot, is_async):
+    func = ("async " if is_async else "") + f"generator function {name}"
+    actual = self._print_as_expected_type(annot)
+    message = f"Bad return type {actual!r} for {func}"
+    if is_async:
+      details = "Expected AsyncGenerator, AsyncIterable or AsyncIterator"
+    else:
+      details = "Expected Generator, Iterable or Iterator"
+    self.error(stack, message, details)
+
   @_error_name("bad-concrete-type")
   def bad_concrete_type(self, stack, node, formal, actual, bad):
-    expected, actual, _, protocol_details = self._print_as_return_types(
-        node, formal, actual, bad)
+    expected, actual, _, protocol_details, nis_details = (
+        self._print_as_return_types(node, formal, actual, bad))
     details = ["       Expected: ", expected, "\n",
                "Actually passed: ", actual]
-    details.extend(protocol_details)
+    details.extend(protocol_details + nis_details)
     self.error(
         stack, "Invalid instantiation of generic class", "".join(details))
 
+  def _show_variable(self, var):
+    """Show variable as 'name: typ' or 'pyval: typ' if available."""
+    val = var.data[0]
+    name = val.vm.get_var_name(var)
+    typ = self._join_printed_types(
+        self._print_as_actual_type(t) for t in var.data)
+    if name:
+      return f"'{name}: {typ}'"
+    elif len(var.data) == 1 and hasattr(val, "pyval"):
+      return f"'{val.pyval!r}: {typ}'"
+    else:
+      return f"'{typ}'"
+
   def unsupported_operands(self, stack, operator, var1, var2):
-    left = self._join_printed_types(
-        self._print_as_actual_type(t) for t in var1.data)
-    right = self._join_printed_types(
-        self._print_as_actual_type(t) for t in var2.data)
+    left = self._show_variable(var1)
+    right = self._show_variable(var2)
     details = "No attribute %r on %s" % (operator, left)
     if operator in slots.REVERSE_NAME_MAPPING:
       details += " or %r on %s" % (slots.REVERSE_NAME_MAPPING[operator], right)
@@ -894,11 +953,17 @@ class ErrorLog(ErrorLogBase):
 
   @_error_name("unsupported-operands")
   def _unsupported_operands(self, stack, operator, *operands, details=None):
-    self.error(
-        stack, "unsupported operand type(s) for %s: %s" % (
-            slots.SYMBOL_MAPPING[operator],
-            " and ".join(repr(operand) for operand in operands)),
-        details=details)
+    """Unsupported operands."""
+    args = " and ".join(str(operand) for operand in operands)
+    if operator in slots.COMPARES:
+      symbol = operator
+      details = f"Primitive types {args} are not comparable."
+      self.error(stack, f"unsupported operand types for {symbol}",
+                 details=details)
+    else:
+      symbol = slots.SYMBOL_MAPPING[operator]
+      self.error(stack, f"unsupported operand type(s) for {symbol}: {args}",
+                 details=details)
 
   def invalid_annotation(self,
                          stack,
@@ -1071,6 +1136,8 @@ class ErrorLog(ErrorLogBase):
 
   @_error_name("annotation-type-mismatch")
   def annotation_type_mismatch(self, stack, annot, binding, name):
+    # TODO(rpalaguachi): Include detailed error message for
+    # NonIterableStringError when a `str` is assigned to a string iterable.
     """Invalid combination of annotation and assignment."""
     if annot is None:
       return
