@@ -30,6 +30,15 @@ def _is_callback_protocol(typ):
           "__call__" in typ.protocol_attributes)
 
 
+class NonIterableStrError(Exception):
+  """Error for matching `str` against `Iterable[str]`/`Sequence[str]`/etc."""
+
+  def __init__(self, left_type, other_type):
+    super().__init__()
+    self.left_type = left_type
+    self.other_type = other_type
+
+
 class ProtocolError(Exception):
 
   def __init__(self, left_type, other_type):
@@ -62,6 +71,7 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
     self._node = node
     self._protocol_cache = set()
     self._protocol_error = None
+    self._noniterable_str_error = None
     self._error_subst = None
 
   @contextlib.contextmanager
@@ -106,6 +116,7 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
     if alias_map:
       subst.uf = alias_map
     self._protocol_error = None
+    self._noniterable_str_error = None
     self._error_subst = None
     self_subst = None
     for name, formal in formal_args:
@@ -114,8 +125,10 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
       if subst is None:
         formal = self.vm.annotations_util.sub_one_annotation(
             self._node, formal, [self._error_subst or {}])
+
         return None, function.BadParam(
-            name=name, expected=formal, protocol_error=self._protocol_error)
+            name=name, expected=formal, protocol_error=self._protocol_error,
+            noniterable_str_error=self._noniterable_str_error)
       if name == "self":
         self_subst = subst
     if self_subst:
@@ -151,9 +164,10 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
       except StopIteration:
         break
       self._protocol_error = None
+      self._noniterable_str_error = None
       if self.match_var_against_type(var, other_type, {}, view) is None:
         if self._node.HasCombination(list(view.values())):
-          bad.append((view, self._protocol_error))
+          bad.append((view, self._protocol_error, self._noniterable_str_error))
         # To get complete error messages, we need to collect all bad views, so
         # we can't skip any.
         skip_future = False
@@ -515,7 +529,7 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
       if isinstance(left.instance, abstract.BaseValue):
         param = left.instance.get_instance_type_parameter(left.param.name)
         # If left resolves to itself
-        # (see tests/py3/test_enums:EnumOverlayTest.test_unique_enum_in_dict),
+        # (see tests/test_enums:EnumOverlayTest.test_unique_enum_in_dict),
         # calling _match_all_bindings would lead to an infinite recursion error.
         if param.bindings and not any(v is left for v in param.data):
           return self._match_all_bindings(param, other_type, subst, view)
@@ -685,8 +699,9 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
             left, other_type.formal_type_parameters[abstract_utils.T], subst,
             view)
     elif isinstance(other_type, class_mixin.Class):
-      if (self.vm.options.enforce_noniterable_strings and
-          self._enforce_noniterable_str(left.get_class(), other_type)):
+      if self._enforce_noniterable_str(left.get_class(), other_type):
+        self._noniterable_str_error = NonIterableStrError(left.get_class(),
+                                                          other_type)
         return None
       base = self.match_from_mro(left.get_class(), other_type)
       if base is None:
@@ -798,7 +813,7 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
         # same value, but substituting from a concrete tuple into an abstract
         # one typically happens during operations like tuple iteration, when
         # values are indeed preserved. See
-        # tests.py3.test_typing.LiteralTest.test_iterate for a case in which
+        # tests.test_typing2.LiteralTest.test_iterate for a case in which
         # this is important.
         copy_params_directly = (
             class_param.full_name == f"{left.full_name}.{abstract_utils.T}")
@@ -894,13 +909,6 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
     left_cls = left.get_class()
     if isinstance(left_cls, abstract.AMBIGUOUS_OR_EMPTY):
       return subst
-    elif (len(left_cls.template) == 1 and
-          other_type.full_name == "typing.Mapping"):
-      # TODO(rechen): This check is a workaround to prevent List from matching
-      # against Mapping. What we should actually do is detect the mismatch
-      # between the type parameters in List's and Mapping's abstract methods,
-      # but that's tricky to do.
-      return None
     elif left_cls.is_dynamic:
       return self._subst_with_type_parameters_from(subst, other_type)
     left_attributes = self._get_attribute_names(left)
@@ -950,11 +958,32 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
         resolved_attribute.PasteBinding(b)
     return resolved_attribute
 
+  def _get_type(self, value):
+    cls = value.get_class()
+    if not cls:
+      return None
+    if (not isinstance(cls, (abstract.PyTDClass, abstract.InterpreterClass)) or
+        not cls.template):
+      return cls
+    parameters = {}
+    for param in cls.template:
+      param_value = value.get_instance_type_parameter(param.name)
+      types = list(filter(None, (self._get_type(v) for v in param_value.data)))
+      if not types:
+        break
+      parameters[param.name] = self.vm.merge_values(types)
+    else:
+      # If 'value' provides non-empty values for all of its class's parameters,
+      # then we construct a ParameterizedClass so that the parameter values are
+      # considered in matching.
+      return abstract.ParameterizedClass(cls, parameters, self.vm)
+    return cls
+
   def _get_attribute_types(self, other_type, attribute):
     if not abstract_utils.is_callable(attribute):
-      cls = attribute.get_class()
-      if cls:
-        yield cls
+      typ = self._get_type(attribute)
+      if typ:
+        yield typ
       return
     converter = self.vm.convert.pytd_convert
     for signature in abstract_utils.get_signatures(attribute):
@@ -1009,30 +1038,39 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
       # TODO(rechen): Even if other_type isn't parameterized, we should run
       # _match_protocol_attribute to catch mismatches in method signatures.
       return subst
-    # The entire match succeeds if left_attribute matches *any* binding of
-    # protocol_attribute_var. A binding matches if *any* options for
-    # left_attribute match *all* options for the binding's types.
-    bad_matches = []
-    for protocol_attribute in protocol_attribute_var.data:
-      protocol_attribute_types = list(
-          self._get_attribute_types(other_type, protocol_attribute))
-      for v in left_attribute.data:
-        new_substs = []
+    # Every binding of left_attribute needs to match at least one binding of
+    # protocol_attribute_var.
+    new_substs = []
+    for new_view in abstract_utils.get_views([left_attribute], self._node):
+      new_view.update(view)
+      bad_matches = []
+      for protocol_attribute in protocol_attribute_var.data:
+        # For this binding of left_attribute to match this binding of
+        # protocol_attribute_var, *all* options in protocol_attribute_types need
+        # to match.
+        protocol_attribute_types = list(
+            self._get_attribute_types(other_type, protocol_attribute))
         for protocol_attribute_type in protocol_attribute_types:
-          match_result = self._match_type_against_type(
-              v, protocol_attribute_type, subst, view)
+          match_result = self.match_var_against_type(
+              left_attribute, protocol_attribute_type, subst, new_view)
           if match_result is None:
-            bad_matches.append((v, protocol_attribute))
+            bad_matches.append(
+                (new_view[left_attribute].data, protocol_attribute))
             break
           else:
             new_substs.append(match_result)
         else:
-          return self._merge_substs(subst, new_substs)
-    bad_left, bad_right = zip(*bad_matches)
-    self._protocol_error = ProtocolTypeError(
-        left_cls, other_type, attribute, self.vm.merge_values(bad_left),
-        self.vm.merge_values(bad_right))
-    return None
+          # We've successfully matched all options in protocol_attribute_types.
+          break
+      else:
+        # This binding of left_attribute has not matched any binding of
+        # protocol_attribute_var.
+        bad_left, bad_right = zip(*bad_matches)
+        self._protocol_error = ProtocolTypeError(
+            left_cls, other_type, attribute, self.vm.merge_values(bad_left),
+            self.vm.merge_values(bad_right))
+        return None
+    return self._merge_substs(subst, new_substs)
 
   def _get_concrete_values_and_classes(self, var):
     # TODO(rechen): For type parameter instances, we should extract the concrete
@@ -1095,14 +1133,17 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
   def _enforce_noniterable_str(self, left, other_type):
     """Enforce a str to NOT be matched against a conflicting iterable type."""
     conflicting_iter_types = ["typing.Iterable", "typing.Sequence",
-                              "typing.Collection", "typing.Container",
-                              "typing.Mapping",]
+                              "typing.Collection", "typing.Container",]
     str_types = ["builtins.str", "builtins.unicode",]
-    if (left.full_name in str_types and
-        other_type.full_name in conflicting_iter_types):
-      return True
 
-    return False
+    if (other_type.full_name not in conflicting_iter_types
+        or left.full_name not in str_types):
+      return False  # Reject uninterested type combinations
+    if isinstance(other_type, abstract.ParameterizedClass):
+      type_param = other_type.get_formal_type_parameter("_T").full_name
+      return type_param in str_types
+
+    return False  # Don't enforce against Iterable[Any]
 
   def _subst_with_type_parameters_from(self, subst, typ):
     subst = subst.copy()
