@@ -58,17 +58,29 @@ class AddMetaclass(abstract.PyTDFunction):
         meta, self.vm, self.module_name).to_variable(node)
 
 
-class WithMetaclassInstance(abstract.BaseValue):
+class WithMetaclassInstance(abstract.BaseValue, class_mixin.Class):
   """Anonymous class created by with_metaclass."""
 
   def __init__(self, vm, cls, bases):
     super().__init__("WithMetaclassInstance", vm)
-    self.cls = cls
+    class_mixin.Class.init_mixin(self, cls)
     self.bases = bases
 
   def get_class(self):
     return self.cls
 
+  def get_own_attributes(self):
+    if isinstance(self.cls, class_mixin.Class):
+      return self.cls.get_own_attributes()
+    else:
+      return set()
+
+  def get_own_abstract_methods(self):
+    if isinstance(self.cls, class_mixin.Class):
+      return self.cls.get_own_abstract_methods()
+    else:
+      return set()
+
 
 class WithMetaclass(abstract.PyTDFunction):
   """Implements with_metaclass."""
