@@ -79,11 +79,8 @@ class Attrs(classgen.Decorator):
           classgen.add_member(node, cls, name, attr.typ)
           if attrib.has_type and isinstance(cls, abstract.InterpreterClass):
             # Add the attrib to the class's __annotations__ dict.
-            annotations_dict = abstract_utils.get_annotations_dict(cls.members)
-            if annotations_dict is None:
-              annotations_dict = abstract.AnnotationsDict({}, self.vm)
-              cls.members["__annotations__"] = annotations_dict.to_variable(
-                  self.vm.root_node)
+            annotations_dict = classgen.get_or_create_annotations_dict(
+                cls.members, self.vm)
             annotations_dict.annotated_locals[name] = abstract_utils.Local(
                 node, None, attrib.typ, orig, self.vm)
         else:
@@ -196,7 +193,7 @@ class Attrib(classgen.FieldConstructor):
           self.vm.annotations_util.get_callable_type_parameter_names(type_var))
       typ = self.vm.annotations_util.extract_annotation(
           node, type_var, "attr.ib", self.vm.simple_stack(),
-          allowed_type_params=allowed_type_params, use_not_supported_yet=False)
+          allowed_type_params=allowed_type_params)
     elif default_var:
       typ = get_type_from_default(default_var, self.vm)
     elif conv_out:
