@@ -22,10 +22,6 @@ call_metaclass_init is called, allowing EnumMetaInit to transform the PyTDClass
 into a proper enum.
 """
 
-# TODO(tsudol):
-# - Flag b/194136075
-# - pyis that aren't formatted correctly
-
 import logging
 
 from pytype import abstract
@@ -48,6 +44,7 @@ class EnumOverlay(overlay.Overlay):
       member_map = {
           "Enum": EnumBuilder,
           "EnumMeta": EnumMeta,
+          "IntEnum": IntEnumBuilder,
       }
     else:
       member_map = {}
@@ -58,10 +55,10 @@ class EnumOverlay(overlay.Overlay):
 class EnumBuilder(abstract.PyTDClass):
   """Overlays enum.Enum."""
 
-  def __init__(self, vm):
+  def __init__(self, vm, name="Enum"):
     enum_ast = vm.loader.import_name("enum")
-    pyval = enum_ast.Lookup("enum.Enum")
-    super().__init__("Enum", pyval, vm)
+    pyval = enum_ast.Lookup(f"enum.{name}")
+    super().__init__(name, pyval, vm)
 
   def make_class(self, node, name_var, bases, class_dict_var, cls_var,
                  new_class_var=None, is_decorated=False):
@@ -87,8 +84,9 @@ class EnumBuilder(abstract.PyTDClass):
     # signature for __new__, rather than the value lookup signature.
     # Note that super().call or _call_new_and_init won't work here, because
     # they don't raise FailedFunctionCall.
-    self.load_lazy_attribute("__new__")
-    pytd_new = abstract_utils.get_atomic_value(self.members["__new__"])
+    node, pytd_new_var = self.vm.attribute_handler.get_attribute(
+        node, self, "__new__", self.to_binding(node))
+    pytd_new = abstract_utils.get_atomic_value(pytd_new_var)
     # There are two signatures for __new__. We want the longer one.
     sig = max(
         pytd_new.signatures, key=lambda s: s.signature.maximum_param_count())
@@ -152,6 +150,13 @@ class EnumBuilder(abstract.PyTDClass):
         class_type=EnumInstance)
 
 
+class IntEnumBuilder(EnumBuilder):
+  """Overlays enum.IntEnum using EnumBuilder."""
+
+  def __init__(self, vm):
+    super().__init__(vm, name="IntEnum")
+
+
 class EnumInstance(abstract.InterpreterClass):
   """A wrapper for classes that subclass enum.Enum."""
 
@@ -188,6 +193,9 @@ class EnumInstance(abstract.InterpreterClass):
 
 class EnumCmpEQ(abstract.SimpleFunction):
   """Implements the functionality of __eq__ for an enum."""
+  # b/195136939: Enum equality checks could be made more exact/precise by
+  # comparing the members' names. However, this causes issues when enums are
+  # used in an if statement; see the bug for examples.
 
   def __init__(self, vm):
     super().__init__(
@@ -213,11 +221,7 @@ class EnumCmpEQ(abstract.SimpleFunction):
       other = abstract_utils.get_atomic_value(other_var)
     except abstract_utils.ConversionError:
       return node, self.vm.convert.build_bool(node)
-    return node, self.vm.convert.build_bool(
-        node,
-        this.cls == other.cls and
-        "name" in this.members and
-        this.members["name"] == other.members.get("name"))
+    return node, self.vm.convert.build_bool(node, this.cls == other.cls)
 
 
 class EnumMeta(abstract.PyTDClass):
@@ -281,7 +285,8 @@ class EnumMetaInit(abstract.SimpleFunction):
         node=node,
         name="__new__",
         params=[
-            overlay_utils.Param("value", member_type)
+            overlay_utils.Param("value",
+                                abstract.Union([member_type, cls], self.vm))
         ],
         return_type=cls)
 
@@ -331,20 +336,41 @@ class EnumMetaInit(abstract.SimpleFunction):
     else:
       return node, self.vm.convert.build_int(node)
 
+  def _wrap_value(self, node, value, base_type):
+    # Process an enum member's value for use as an argument. Returns a tuple
+    # that can be used for Args.posargs.
+    # If value is not a tuple already, make it one.
+    # Then, if the base type is tuple, wrap it again.
+    arg = abstract_utils.maybe_extract_tuple(value)
+    if base_type.full_name == "builtins.tuple":
+      arg = (self.vm.convert.build_tuple(node, arg),)
+    return arg
+
   def _mark_dynamic_enum(self, cls):
     # Checks if the enum should be marked as having dynamic attributes.
-    # The most typical use of custom subclasses of EnumMeta is to add more
-    # members to the enum, or to (for example) make attribute access
-    # case-insensitive. Treat such enums as having dynamic attributes.
     # Of course, if it's already marked dynamic, don't accidentally unmark it.
     if cls.maybe_missing_members:
       return
+    # Custom __init__ or __new__ methods are used to add new members to enum
+    # members. Until we can support that better, just mark them as dynamic.
+    if "__init__" in cls or "__new__" in cls:
+      cls.maybe_missing_members = True
+      return
+    # The most typical use of custom subclasses of EnumMeta is to add more
+    # members to the enum, or to (for example) make attribute access
+    # case-insensitive. Treat such enums as having dynamic attributes.
     if cls.cls and cls.cls.full_name != "enum.EnumMeta":
       cls.maybe_missing_members = True
       return
     for base_var in cls.bases():
       for base in base_var.data:
-        if base.is_enum and base.cls and base.cls.full_name != "enum.EnumMeta":
+        if not base.is_enum:
+          continue
+        # Interpreter classes don't have "maybe_missing_members" set even if
+        # they have _HAS_DYNAMIC_ATTRIBUTES. But for enums, those markers should
+        # apply to the whole class.
+        if ((base.cls and base.cls.full_name != "enum.EnumMeta") or
+            base.maybe_missing_members or base.has_dynamic_attributes()):
           cls.maybe_missing_members = True
           return
 
@@ -352,6 +378,8 @@ class EnumMetaInit(abstract.SimpleFunction):
     member_types = []
     base_type = self._get_base_type(cls.bases())
     for name, local in self._get_class_locals(node, cls.name, cls.members):
+      if name in abstract_utils.DYNAMIC_ATTRIBUTE_MARKERS:
+        continue
       # Build instances directly, because you can't call instantiate() when
       # creating the class -- pytype complains about recursive types.
       member = abstract.Instance(cls, self.vm)
@@ -361,7 +389,7 @@ class EnumMetaInit(abstract.SimpleFunction):
       if self._is_orig_auto(value):
         node, value = self._call_generate_next_value(node, cls, name)
       if base_type:
-        args = function.Args(posargs=(value,))
+        args = function.Args(posargs=self._wrap_value(node, value, base_type))
         node, value = base_type.call(node, base_type.to_binding(node), args)
       member.members["value"] = value
       member.members["_value_"] = value
@@ -375,6 +403,9 @@ class EnumMetaInit(abstract.SimpleFunction):
     else:
       member_type = self.vm.convert.unsolvable
     cls.member_type = member_type
+    # Because we overwrite __new__, we need to mark dynamic enums here.
+    # Of course, this can be moved later once custom __init__ is supported.
+    self._mark_dynamic_enum(cls)
     cls.members["__new__"] = self._make_new(node, member_type, cls)
     cls.members["__eq__"] = EnumCmpEQ(self.vm).to_variable(node)
     # _generate_next_value_ is used as a static method of the enum, not a class
@@ -387,7 +418,6 @@ class EnumMetaInit(abstract.SimpleFunction):
         node, new_gnv = self.vm.load_special_builtin("staticmethod").call(
             node, None, args)
         cls.members["_generate_next_value_"] = new_gnv
-    self._mark_dynamic_enum(cls)
     return node
 
   def _setup_pytdclass(self, node, cls):
@@ -395,6 +425,8 @@ class EnumMetaInit(abstract.SimpleFunction):
     members = dict(cls._member_map)  # pylint: disable=protected-access
     member_types = []
     for name, pytd_val in members.items():
+      if name in abstract_utils.DYNAMIC_ATTRIBUTE_MARKERS:
+        continue
       # Only constants need to be transformed. We assume that enums in type
       # stubs are full realized, i.e. there are no auto() calls and the members
       # already have values of the base type.
@@ -420,13 +452,15 @@ class EnumMetaInit(abstract.SimpleFunction):
       cls._member_map[name] = member  # pylint: disable=protected-access
       cls.members[name] = member.to_variable(node)
       member_types.append(value_type)
+    # Because we overwrite __new__, we need to mark dynamic enums here.
+    # Of course, this can be moved later once custom __init__ is supported.
+    self._mark_dynamic_enum(cls)
     if not member_types:
       member_types.append(pytd.AnythingType())
     member_type = self.vm.convert.constant_to_value(
         pytd_utils.JoinTypes(member_types))
     cls.members["__new__"] = self._make_new(node, member_type, cls)
     cls.members["__eq__"] = EnumCmpEQ(self.vm).to_variable(node)
-    self._mark_dynamic_enum(cls)
     return node
 
   def call(self, node, func, args, alias_map=None):
