@@ -1,7 +1,4 @@
-"""Opcode definitions for both Python 2 and Python 3."""
-
-import six
-import six.moves
+"""Opcode definitions."""
 
 # We define all-uppercase classes, to match their opcode names:
 # pylint: disable=invalid-name
@@ -154,11 +151,6 @@ class OpcodeWithArg(Opcode):
     return True
 
 
-class STOP_CODE(Opcode):
-  __slots__ = ()
-  FLAGS = NO_NEXT
-
-
 class POP_TOP(Opcode):
   __slots__ = ()
 
@@ -199,10 +191,6 @@ class UNARY_NOT(Opcode):
   __slots__ = ()
 
 
-class UNARY_CONVERT(Opcode):
-  __slots__ = ()
-
-
 class UNARY_INVERT(Opcode):
   __slots__ = ()
 
@@ -223,10 +211,6 @@ class BINARY_MULTIPLY(Opcode):
   __slots__ = ()
 
 
-class BINARY_DIVIDE(Opcode):
-  __slots__ = ()
-
-
 class BINARY_MODULO(Opcode):
   __slots__ = ()
 
@@ -259,54 +243,6 @@ class INPLACE_TRUE_DIVIDE(Opcode):
   __slots__ = ()
 
 
-class SLICE_0(Opcode):
-  __slots__ = ()
-
-
-class SLICE_1(Opcode):
-  __slots__ = ()
-
-
-class SLICE_2(Opcode):
-  __slots__ = ()
-
-
-class SLICE_3(Opcode):
-  __slots__ = ()
-
-
-class STORE_SLICE_0(Opcode):
-  __slots__ = ()
-
-
-class STORE_SLICE_1(Opcode):
-  __slots__ = ()
-
-
-class STORE_SLICE_2(Opcode):
-  __slots__ = ()
-
-
-class STORE_SLICE_3(Opcode):
-  __slots__ = ()
-
-
-class DELETE_SLICE_0(Opcode):
-  __slots__ = ()
-
-
-class DELETE_SLICE_1(Opcode):
-  __slots__ = ()
-
-
-class DELETE_SLICE_2(Opcode):
-  __slots__ = ()
-
-
-class DELETE_SLICE_3(Opcode):
-  __slots__ = ()
-
-
 class GET_AITER(Opcode):
   __slots__ = ()
 
@@ -328,17 +264,13 @@ class END_ASYNC_FOR(Opcode):
   # exception, we do not include NO_NEXT in the flags because doing so would
   # cause the return statement for an async method to be skipped, leading to
   # an incorrect return type.
-  # See tests/py3/test_stdlib:StdlibTestsFeatures.test_async_iter and
-  # tests/py3/test_coroutine:GeneratorFeatureTest.test_async_for_pyi for tests
+  # See tests/test_stdlib2:StdlibTestsFeatures.test_async_iter and
+  # tests/test_coroutine:GeneratorFeatureTest.test_async_for_pyi for tests
   # that fail if we add NO_NEXT.
   FLAGS = HAS_JUNKNOWN
   __slots__ = ()
 
 
-class STORE_MAP(Opcode):
-  __slots__ = ()
-
-
 class INPLACE_ADD(Opcode):
   __slots__ = ()
 
@@ -351,10 +283,6 @@ class INPLACE_MULTIPLY(Opcode):
   __slots__ = ()
 
 
-class INPLACE_DIVIDE(Opcode):
-  __slots__ = ()
-
-
 class INPLACE_MODULO(Opcode):
   __slots__ = ()
 
@@ -399,30 +327,10 @@ class GET_YIELD_FROM_ITER(Opcode):
   __slots__ = ()
 
 
-class STORE_LOCALS(Opcode):
-  __slots__ = ()
-
-
 class PRINT_EXPR(Opcode):
   __slots__ = ()
 
 
-class PRINT_ITEM(Opcode):
-  __slots__ = ()
-
-
-class PRINT_NEWLINE(Opcode):
-  __slots__ = ()
-
-
-class PRINT_ITEM_TO(Opcode):
-  __slots__ = ()
-
-
-class PRINT_NEWLINE_TO(Opcode):
-  __slots__ = ()
-
-
 class LOAD_BUILD_CLASS(Opcode):
   __slots__ = ()
 
@@ -461,12 +369,6 @@ class BREAK_LOOP(Opcode):
   __slots__ = ()
 
 
-class WITH_CLEANUP(Opcode):
-  # This opcode changes the block stack, but it should never change its depth.
-  FLAGS = HAS_JUNKNOWN  # might call __exit__
-  __slots__ = ()
-
-
 class WITH_CLEANUP_START(Opcode):
   FLAGS = HAS_JUNKNOWN  # might call __exit__
   __slots__ = ()
@@ -476,10 +378,6 @@ class WITH_CLEANUP_FINISH(Opcode):
   __slots__ = ()
 
 
-class LOAD_LOCALS(Opcode):
-  __slots__ = ()
-
-
 class RETURN_VALUE(Opcode):
   FLAGS = HAS_JUNKNOWN | NO_NEXT
   __slots__ = ()
@@ -493,11 +391,6 @@ class SETUP_ANNOTATIONS(Opcode):
   __slots__ = ()
 
 
-class EXEC_STMT(Opcode):
-  FLAGS = HAS_JUNKNOWN
-  __slots__ = ()
-
-
 class YIELD_VALUE(Opcode):
   FLAGS = HAS_JUNKNOWN
   __slots__ = ()
@@ -513,10 +406,6 @@ class END_FINALLY(Opcode):
   __slots__ = ()
 
 
-class BUILD_CLASS(Opcode):
-  __slots__ = ()
-
-
 class POP_EXCEPT(Opcode):
   __slots__ = ()
 
@@ -571,11 +460,6 @@ class DELETE_GLOBAL(OpcodeWithArg):  # Indexes into name list
   __slots__ = ()
 
 
-class DUP_TOPX(OpcodeWithArg):  # Arg: Number of items to duplicate
-  FLAGS = HAS_ARGUMENT
-  __slots__ = ()
-
-
 class LOAD_CONST(OpcodeWithArg):  # Arg: Index in const list
   FLAGS = HAS_ARGUMENT|HAS_CONST
   __slots__ = ()
@@ -921,127 +805,11 @@ class LOAD_FOLDED_CONST(OpcodeWithArg):  # A fake opcode used internally
     return self.basic_str() + " " + str(self.arg.value)
 
 
-python2_mapping = {
-    0: STOP_CODE,  # removed in Python 3
-    1: POP_TOP,
-    2: ROT_TWO,
-    3: ROT_THREE,
-    4: DUP_TOP,
-    5: ROT_FOUR,  # becomes DUP_TOP_TWO in Python 3
-    9: NOP,
-    10: UNARY_POSITIVE,
-    11: UNARY_NEGATIVE,
-    12: UNARY_NOT,
-    13: UNARY_CONVERT,  # removed in Python 3
-    15: UNARY_INVERT,
-    19: BINARY_POWER,
-    20: BINARY_MULTIPLY,
-    21: BINARY_DIVIDE,  # removed in Python 3
-    22: BINARY_MODULO,
-    23: BINARY_ADD,
-    24: BINARY_SUBTRACT,
-    25: BINARY_SUBSCR,
-    26: BINARY_FLOOR_DIVIDE,
-    27: BINARY_TRUE_DIVIDE,
-    28: INPLACE_FLOOR_DIVIDE,
-    29: INPLACE_TRUE_DIVIDE,
-    30: SLICE_0,  # removed in Python 3
-    31: SLICE_1,  # removed in Python 3
-    32: SLICE_2,  # removed in Python 3
-    33: SLICE_3,  # removed in Python 3
-    40: STORE_SLICE_0,  # removed in Python 3
-    41: STORE_SLICE_1,  # removed in Python 3
-    42: STORE_SLICE_2,  # removed in Python 3
-    43: STORE_SLICE_3,  # removed in Python 3
-    50: DELETE_SLICE_0,  # removed in Python 3
-    51: DELETE_SLICE_1,  # removed in Python 3
-    52: DELETE_SLICE_2,  # removed in Python 3
-    53: DELETE_SLICE_3,  # removed in Python 3
-    54: STORE_MAP,
-    55: INPLACE_ADD,
-    56: INPLACE_SUBTRACT,
-    57: INPLACE_MULTIPLY,
-    58: INPLACE_DIVIDE,  # removed in Python 3
-    59: INPLACE_MODULO,
-    60: STORE_SUBSCR,
-    61: DELETE_SUBSCR,
-    62: BINARY_LSHIFT,
-    63: BINARY_RSHIFT,
-    64: BINARY_AND,
-    65: BINARY_XOR,
-    66: BINARY_OR,
-    67: INPLACE_POWER,
-    68: GET_ITER,
-    70: PRINT_EXPR,
-    71: PRINT_ITEM,  # becomes LOAD_BUILD_CLASS in Python 3
-    72: PRINT_NEWLINE,  # becomes YIELD_FROM in Python 3
-    73: PRINT_ITEM_TO,
-    74: PRINT_NEWLINE_TO,
-    75: INPLACE_LSHIFT,
-    76: INPLACE_RSHIFT,
-    77: INPLACE_AND,
-    78: INPLACE_XOR,
-    79: INPLACE_OR,
-    80: BREAK_LOOP,
-    81: WITH_CLEANUP,
-    82: LOAD_LOCALS,  # removed in Python 3
-    83: RETURN_VALUE,
-    84: IMPORT_STAR,
-    85: EXEC_STMT,  # removed in Python 3
-    86: YIELD_VALUE,
-    87: POP_BLOCK,
-    88: END_FINALLY,
-    89: BUILD_CLASS,  # becomes POP_EXCEPT in Python 3
-    90: STORE_NAME,
-    91: DELETE_NAME,
-    92: UNPACK_SEQUENCE,
-    93: FOR_ITER,
-    94: LIST_APPEND,  # becomes UNPACK_EX in Python 3
-    95: STORE_ATTR,
-    96: DELETE_ATTR,
-    97: STORE_GLOBAL,
-    98: DELETE_GLOBAL,
-    99: DUP_TOPX,  # removed in Python 3
-    100: LOAD_CONST,
-    101: LOAD_NAME,
-    102: BUILD_TUPLE,
-    103: BUILD_LIST,
-    104: BUILD_SET,
-    105: BUILD_MAP,
-    106: LOAD_ATTR,
-    107: COMPARE_OP,
-    108: IMPORT_NAME,
-    109: IMPORT_FROM,
-    110: JUMP_FORWARD,
-    111: JUMP_IF_FALSE_OR_POP,
-    112: JUMP_IF_TRUE_OR_POP,
-    113: JUMP_ABSOLUTE,
-    114: POP_JUMP_IF_FALSE,
-    115: POP_JUMP_IF_TRUE,
-    116: LOAD_GLOBAL,
-    119: CONTINUE_LOOP,
-    120: SETUP_LOOP,
-    121: SETUP_EXCEPT,
-    122: SETUP_FINALLY,
-    124: LOAD_FAST,
-    125: STORE_FAST,
-    126: DELETE_FAST,
-    130: RAISE_VARARGS,
-    131: CALL_FUNCTION,
-    132: MAKE_FUNCTION,
-    133: BUILD_SLICE,
-    134: MAKE_CLOSURE,
-    135: LOAD_CLOSURE,
-    136: LOAD_DEREF,
-    137: STORE_DEREF,
-    140: CALL_FUNCTION_VAR,
-    141: CALL_FUNCTION_KW,
-    142: CALL_FUNCTION_VAR_KW,
-    143: SETUP_WITH,
-    145: EXTENDED_ARG,  # moved to 144 in Python 3, 145 becomes LIST_APPEND
-    146: SET_ADD,
-    147: MAP_ADD,
-}
+def _overlay_mapping(mapping, new_entries):
+  ret = mapping.copy()
+  ret.update(new_entries)
+  return dict((k, v) for k, v in ret.items() if v is not None)
+
 
 python_3_5_mapping = {
     1: POP_TOP,
@@ -1084,8 +852,8 @@ python_3_5_mapping = {
     68: GET_ITER,
     69: GET_YIELD_FROM_ITER,
     70: PRINT_EXPR,
-    71: LOAD_BUILD_CLASS,  # PRINT_ITEM in Python 2
-    72: YIELD_FROM,  # PRINT_NEWLINE in Python 2
+    71: LOAD_BUILD_CLASS,
+    72: YIELD_FROM,
     73: GET_AWAITABLE,
     75: INPLACE_LSHIFT,
     76: INPLACE_RSHIFT,
@@ -1100,12 +868,12 @@ python_3_5_mapping = {
     86: YIELD_VALUE,
     87: POP_BLOCK,
     88: END_FINALLY,
-    89: POP_EXCEPT,  # BUILD_CLASS in Python 2
+    89: POP_EXCEPT,
     90: STORE_NAME,
     91: DELETE_NAME,
     92: UNPACK_SEQUENCE,
     93: FOR_ITER,
-    94: UNPACK_EX,  # LIST_APPEND in Python 2
+    94: UNPACK_EX,
     95: STORE_ATTR,
     96: DELETE_ATTR,
     97: STORE_GLOBAL,
@@ -1147,11 +915,11 @@ python_3_5_mapping = {
     141: CALL_FUNCTION_KW,
     142: CALL_FUNCTION_VAR_KW,
     143: SETUP_WITH,
-    144: EXTENDED_ARG,  # 145 in Python 2
-    145: LIST_APPEND,  # 94 in Python 2
+    144: EXTENDED_ARG,
+    145: LIST_APPEND,
     146: SET_ADD,
     147: MAP_ADD,
-    148: LOAD_CLASSDEREF,  # not in Python 2
+    148: LOAD_CLASSDEREF,
     149: BUILD_LIST_UNPACK,
     150: BUILD_MAP_UNPACK,
     151: BUILD_MAP_UNPACK_WITH_CALL,
@@ -1160,12 +928,6 @@ python_3_5_mapping = {
     154: SETUP_ASYNC_WITH,
 }
 
-
-def _overlay_mapping(mapping, new_entries):
-  ret = mapping.copy()
-  ret.update(new_entries)
-  return dict((k, v) for k, v in ret.items() if v is not None)
-
 python_3_6_mapping = _overlay_mapping(python_3_5_mapping, {
     85: SETUP_ANNOTATIONS,
     127: STORE_ANNOTATION,  # removed in Python 3.7
@@ -1226,7 +988,7 @@ class _LineNumberTableParser:
     assert not len(lnotab) & 1  # lnotab always has an even number of elements
     self.lnotab = lnotab
     self.lineno = firstlineno
-    self.next_addr = six.indexbytes(self.lnotab, 0) if self.lnotab else 0
+    self.next_addr = self.lnotab[0] if self.lnotab else 0
     self.pos = 0
     self.python_version = python_version
 
@@ -1243,7 +1005,7 @@ class _LineNumberTableParser:
       The line number corresponding to the position at i.
     """
     while i >= self.next_addr and self.pos < len(self.lnotab):
-      line_diff = six.indexbytes(self.lnotab, self.pos + 1)
+      line_diff = self.lnotab[self.pos + 1]
       # The Python docs have more details on this weird bit twiddling.
       # https://github.com/python/cpython/blob/master/Objects/lnotab_notes.txt
       # https://github.com/python/cpython/commit/f3914eb16d28ad9eb20fe5133d9aa83658bcc27f
@@ -1253,7 +1015,7 @@ class _LineNumberTableParser:
 
       self.pos += 2
       if self.pos < len(self.lnotab):
-        self.next_addr += six.indexbytes(self.lnotab, self.pos)
+        self.next_addr += self.lnotab[self.pos]
     return self.lineno
 
 
@@ -1291,19 +1053,18 @@ def _bytecode_reader(data, mapping):
   extended_arg = 0
   start = 0
   size = len(data)
-  byte_at = lambda i: six.indexbytes(data, i)
   while pos < size:
-    opcode = byte_at(pos)
+    opcode = data[pos]
     cls = mapping[opcode]
     oparg = None
     if cls is EXTENDED_ARG:
       # EXTENDED_ARG modifies the opcode after it, setting bits 16..31 of
       # its argument.
       assert not extended_arg, "two EXTENDED_ARGs in a row"
-      extended_arg = byte_at(pos+1) << 16 | byte_at(pos+2) << 24
+      extended_arg = data[pos+1] << 16 | data[pos+2] << 24
       bytes_read = 3
     elif cls.FLAGS & HAS_ARGUMENT:
-      oparg = byte_at(pos+1) | byte_at(pos+2) << 8 | extended_arg
+      oparg = data[pos+1] | data[pos+2] << 8 | extended_arg
       extended_arg = 0
       bytes_read = 3
     else:
@@ -1332,15 +1093,14 @@ def _wordcode_reader(data, mapping):
   assert isinstance(data, bytes)
   extended_arg = 0
   start = 0
-  byte_at = lambda i: six.indexbytes(data, i)
-  for pos in six.moves.xrange(0, len(data), 2):
-    opcode = byte_at(pos)
+  for pos in range(0, len(data), 2):
+    opcode = data[pos]
     cls = mapping[opcode]
     if cls is EXTENDED_ARG:
-      oparg = byte_at(pos+1) | extended_arg
+      oparg = data[pos+1] | extended_arg
       extended_arg = oparg << 8
     elif cls.FLAGS & HAS_ARGUMENT:
-      oparg = byte_at(pos+1) | extended_arg
+      oparg = data[pos+1] | extended_arg
       extended_arg = 0
     else:
       oparg = None
@@ -1396,9 +1156,8 @@ def _dis(python_version, data, mapping, reader,
 def dis(data, python_version, *args, **kwargs):
   """Set up version-specific arguments and call _dis()."""
   major, minor = python_version[0], python_version[1]
-  assert major in (2, 3)
+  assert major == 3
   mapping = {
-      (2, 7): python2_mapping,
       (3, 5): python_3_5_mapping,
       (3, 6): python_3_6_mapping,
       (3, 7): python_3_7_mapping,
