@@ -1,4 +1,3 @@
-from pytype import compat
 from pytype.pyc import opcodes
 import unittest
 
@@ -7,16 +6,16 @@ class _TestBase(unittest.TestCase):
   """Base class for all opcodes.dis testing."""
 
   def dis(self, code, **kwargs):
-    """Return the opcodes from disassbling a code sequence."""
-    return opcodes.dis(compat.int_array_to_bytes(code),
+    """Return the opcodes from disassembling a code sequence."""
+    return opcodes.dis(bytes(code),
                        self.python_version, **kwargs)
 
   def assertSimple(self, opcode, name):
-    """Assert that a single opcode byte diassembles to the given name."""
+    """Assert that a single opcode byte disassembles to the given name."""
     self.assertName([opcode], name)
 
   def assertName(self, code, name):
-    """Assert that the first diassembled opcode has the given name."""
+    """Assert that the first disassembled opcode has the given name."""
     self.assertEqual(self.dis(code)[0].name, name)
 
   def assertDisassembly(self, code, expected):
@@ -31,7 +30,7 @@ class _TestBase(unittest.TestCase):
 
   def assertLineNumbers(self, code, co_lnotab, expected):
     """Assert that the opcodes have the expected line numbers."""
-    ops = self.dis(code, co_lnotab=compat.int_array_to_bytes(co_lnotab),
+    ops = self.dis(code, co_lnotab=bytes(co_lnotab),
                    co_firstlineno=1)
     self.assertEqual(len(ops), len(expected))
     for o, e in zip(ops, expected):
@@ -39,96 +38,60 @@ class _TestBase(unittest.TestCase):
 
 
 class CommonTest(_TestBase):
-  """Test bytecodes that are common to Python 2 and 3 using python 2."""
+  """Test bytecodes that are common to multiple Python versions."""
 
-  python_version = (2, 7, 6)
+  python_version = (3, 7)
 
   def test_pop_top(self):
     self.assertSimple(1, 'POP_TOP')
 
   def test_store_name(self):
-    self.assertName([90, 0, 0], 'STORE_NAME')
+    self.assertName([90, 0], 'STORE_NAME')
 
   def test_for_iter(self):
-    self.assertName([93, 0, 0, 9], 'FOR_ITER')
+    self.assertName([93, 0, 9], 'FOR_ITER')
 
   def test_extended_disassembly(self):
     code = [
-        0x7c, 0, 0,  # 0 LOAD_FAST, arg=0,
-        0x7c, 0, 0,  # 3 LOAD_FAST, arg=0,
+        0x7c, 0,  # 0 LOAD_FAST, arg=0,
+        0x7c, 0,  # 3 LOAD_FAST, arg=0,
         0x17,  # 6 BINARY_ADD,
         0x01,  # 7 POP_TOP,
-        0x7c, 0, 0,  # 8 LOAD_FAST, arg=0,
-        0x7c, 0, 0,  # 11 LOAD_FAST, arg=0,
+        0x7c, 0,  # 8 LOAD_FAST, arg=0,
+        0x7c, 0,  # 11 LOAD_FAST, arg=0,
         0x14,  # 14 BINARY_MULTIPLY,
         0x01,  # 15 POP_TOP,
-        0x7c, 0, 0,  # 16 LOAD_FAST, arg=0,
-        0x7c, 0, 0,  # 19 LOAD_FAST, arg=0,
+        0x7c, 0,  # 16 LOAD_FAST, arg=0,
+        0x7c, 0,  # 19 LOAD_FAST, arg=0,
         0x16,  # 22 BINARY_MODULO,
         0x01,  # 23 POP_TOP,
-        0x7c, 0, 0,  # 24 LOAD_FAST, arg=0,
-        0x7c, 0, 0,  # 27 LOAD_FAST, arg=0,
+        0x7c, 0,  # 24 LOAD_FAST, arg=0,
+        0x7c, 0,  # 27 LOAD_FAST, arg=0,
         0x1b,  # 30 BINARY_TRUE_DIVIDE,
         0x01,  # 31 POP_TOP,
-        0x64, 0, 0,  # 32 LOAD_CONST, arg=0,
-        0x53,  # 35 RETURN_VALUE
+        0x64, 0,  # 32 LOAD_CONST, arg=0,
+        0x53, 0,  # 35 RETURN_VALUE
     ]
+    # The POP_TOP instructions are discarded.
     expected = [
         ('LOAD_FAST', 0),
         ('LOAD_FAST', 0),
         ('BINARY_ADD',),
-        ('POP_TOP',),
         ('LOAD_FAST', 0),
         ('LOAD_FAST', 0),
         ('BINARY_MULTIPLY',),
-        ('POP_TOP',),
         ('LOAD_FAST', 0),
         ('LOAD_FAST', 0),
         ('BINARY_MODULO',),
-        ('POP_TOP',),
         ('LOAD_FAST', 0),
         ('LOAD_FAST', 0),
         ('BINARY_TRUE_DIVIDE',),
-        ('POP_TOP',),
         ('LOAD_CONST', 0),
         ('RETURN_VALUE',),
     ]
     self.assertDisassembly(code, expected)
 
 
-class CommonUnder3Test(CommonTest):
-  """Test the common bytecodes using Python 3.5."""
-
-  python_version = (3, 5, 0)
-
-
-class Python2Test(_TestBase):
-  """Test bytecodes specific to Python 2."""
-
-  python_version = (2, 7, 6)
-
-  def test_stop_code(self):
-    self.assertSimple(0, 'STOP_CODE')
-
-  def test_store_map(self):
-    self.assertSimple(54, 'STORE_MAP')
-
-  def test_dup_topx(self):
-    self.assertName([99, 0, 0], 'DUP_TOPX')
-
-  def test_extended_arg(self):
-    code = [
-        0x91, 1, 0,  # 0 EXTENDED_ARG, arg=1,
-        0x64, 2, 0,  # 3 LOAD_CONST, arg=2
-        0x53,  # 6 RETURN_VALUE
-    ]
-    expected = [
-        ('LOAD_CONST', 0x10002),
-        ('RETURN_VALUE',)
-    ]
-    self.assertDisassembly(code, expected)
-
-
 class Python35Test(_TestBase):
   """Test bytecodes specific to Python 3.5."""
 
