@@ -1,15 +1,11 @@
-# python3
-
 """Parse a pyi file using typed_ast."""
 
+import dataclasses
 import hashlib
 import sys
-
 import typing
 from typing import Any, List, Optional, Tuple, Union
 
-import dataclasses
-
 from pytype import utils
 from pytype.ast import debug
 from pytype.pyi import classdef
@@ -25,7 +21,6 @@ from pytype.pytd import pytd_utils
 from pytype.pytd import visitors
 from pytype.pytd.codegen import decorate
 from pytype.pytd.codegen import pytdgen
-
 from typed_ast import ast3
 
 
@@ -89,7 +84,7 @@ class _TypeVar:
     kws = {x.arg for x in node.keywords}
     extra = kws - {"bound", "covariant", "contravariant"}
     if extra:
-      raise ParseError("Unrecognized keyword(s): %s" % ", ".join(extra))
+      raise ParseError(f"Unrecognized keyword(s): {', '.join(extra)}")
     for kw in node.keywords:
       if kw.arg == "bound":
         bound = kw.value
@@ -125,9 +120,9 @@ def _attribute_to_name(node: ast3.Attribute) -> ast3.Name:
   elif isinstance(val, (pytd.NamedType, pytd.Module)):
     prefix = val.name
   else:
-    msg = "Unexpected attribute access on %r [%s]" % (val, type(val))
+    msg = f"Unexpected attribute access on {val!r} [{type(val)}]"
     raise ParseError(msg)
-  return ast3.Name(prefix + "." + node.attr)
+  return ast3.Name(f"{prefix}.{node.attr}")
 
 
 class AnnotationVisitor(visitor.BaseVisitor):
@@ -392,10 +387,9 @@ class GeneratePytdVisitor(visitor.BaseVisitor):
     value = node.value
     for target in node.targets:
       if isinstance(target, ast3.Tuple):
-        if not (isinstance(value, ast3.Tuple) and
-                len(target.elts) == len(value.elts)):
-          msg = ("Cannot unpack %d values for multiple assignment" %
-                 len(target.elts))
+        count = len(target.elts)
+        if not (isinstance(value, ast3.Tuple) and count == len(value.elts)):
+          msg = f"Cannot unpack {count} values for multiple assignment"
           raise ParseError(msg)
         for k, v in zip(target.elts, value.elts):
           out.append(self._assign(node, k, v))
@@ -626,29 +620,19 @@ VersionType = Union[int, Tuple[int, ...]]
 
 def _feature_version(python_version: VersionType) -> int:
   """Get the python feature version for the parser."""
-  def from_major(v):
-    # We only use this to set the feature version, and all pyi files need to
-    # parse as at least python 3.6
-    if v == 2:
-      return 6
-    else:
-      # We don't support host python2, so sys.version = 3.x
-      return sys.version_info.minor
   if isinstance(python_version, int):
-    return from_major(python_version)
+    return sys.version_info.minor
   else:
     python_version = typing.cast(Tuple[int, ...], python_version)
     if len(python_version) == 1:
-      return from_major(python_version[0])
+      return sys.version_info.minor
     else:
-      if python_version[0] == 2:
-        return 6
       return python_version[1]
 
 
 def parse_string(
     src: str,
-    python_version: VersionType,
+    python_version: VersionType = 3,
     name: Optional[str] = None,
     filename: Optional[str] = None,
     platform: Optional[str] = None
@@ -661,7 +645,7 @@ def parse_pyi(
     src: str,
     filename: Optional[str],
     module_name: str,
-    python_version: VersionType,
+    python_version: VersionType = 3,
     platform: Optional[str] = None
 ) -> pytd.TypeDeclUnit:
   """Parse a pyi string."""
@@ -680,7 +664,7 @@ def parse_pyi_debug(
     src: str,
     filename: str,
     module_name: str,
-    python_version: VersionType,
+    python_version: VersionType = 3,
     platform: Optional[str] = None
 ) -> Tuple[pytd.TypeDeclUnit, GeneratePytdVisitor]:
   """Debug version of parse_pyi."""
@@ -702,7 +686,7 @@ def parse_pyi_debug(
   return root, gen_pytd
 
 
-def canonical_pyi(pyi, python_version, multiline_args=False):
+def canonical_pyi(pyi, python_version=3, multiline_args=False):
   """Rewrite a pyi in canonical form."""
   ast = parse_string(pyi, python_version=python_version)
   ast = ast.Visit(visitors.ClassTypeToNamedType())
