@@ -8,18 +8,12 @@ from pytype.pyi import parser
 from pytype.pytd import pytd
 from pytype.pytd import pytd_utils
 from pytype.tests import test_base
-import six
 
 import unittest
 
 IGNORE = object()
 
 
-def get_builtins_source(python_version):
-  return pytd_utils.GetPredefinedFile(
-      "builtins/%d" % python_version[0], "builtins")[1]
-
-
 class _ParserTestBase(test_base.UnitTest):
 
   def check(self, src, expected=None, prologue=None, name=None,
@@ -65,7 +59,7 @@ class _ParserTestBase(test_base.UnitTest):
     with self.assertRaises(parser.ParseError) as e:
       parser.parse_string(textwrap.dedent(src).lstrip(),
                           python_version=self.python_version)
-    six.assertRegex(self, utils.message(e.exception), re.escape(message))
+    self.assertRegex(utils.message(e.exception), re.escape(message))
     self.assertEqual(expected_line, e.exception.line)
 
 
@@ -1337,7 +1331,7 @@ class FunctionTest(_ParserTestBase):
           x = int""")
     self.check_error("""
       def foo(x) -> int:
-          y = int""", 1, "No parameter named y")
+          y = int""", 1, "No parameter named 'y'")
 
   def test_mutator_from_annotation(self):
     self.check("""
@@ -1576,14 +1570,14 @@ class ClassTest(_ParserTestBase):
 
       class Foo(Protocol[T]): ...
     """, """
+      import typing
       from typing import Generic, TypeVar
-      import typing_extensions
 
       from typing_extensions import Protocol
 
       T = TypeVar('T')
 
-      class Foo(typing_extensions.Protocol, Generic[T]): ...
+      class Foo(typing.Protocol, Generic[T]): ...
     """)
 
   def test_bad_typevar_in_mutation(self):
@@ -2248,7 +2242,8 @@ class MergeSignaturesTest(_ParserTestBase):
 class EntireFileTest(_ParserTestBase):
 
   def test_builtins(self):
-    self.check(get_builtins_source(self.python_version), expected=IGNORE)
+    _, builtins = pytd_utils.GetPredefinedFile("builtins", "builtins")
+    self.check(builtins, expected=IGNORE)
 
 
 class AnyTest(_ParserTestBase):
@@ -2819,10 +2814,6 @@ class ParamsTest(test_base.UnitTest):
 
   def test_feature_version(self):
     cases = [
-        [2, 6],
-        [(2,), 6],
-        [(2, 7), 6],
-        [(2, 7, 8), 6],
         [3, sys.version_info.minor],
         [(3,), sys.version_info.minor],
         [(3, 7), 7],
@@ -2908,6 +2899,20 @@ class ParamSpecTest(_ParserTestBase):
       def f2(x: X[int, str]) -> None: ...
     """)
 
+  def test_paramspec_args(self):
+    self.check("""
+      from typing import Callable, ParamSpec, TypeVar
+      P = ParamSpec('P')
+      T = TypeVar('T')
+      def f(x: Callable[P, T], *args: P.args, **kwargs: P.kwargs) -> T: ...
+    """, """
+      from typing import Callable, TypeVar
+
+      T = TypeVar('T')
+
+      def f(x: Callable[..., T], *args, **kwargs) -> T: ...
+    """)
+
 
 class ConcatenateTest(_ParserTestBase):
 
