@@ -210,7 +210,7 @@ class DropBuiltinPrefix(Visitor):
     return self.VisitClassType(node)
 
 
-# TODO(rechen): Get rid of this hack once we drop Python 2 support and all
+# TODO(b/195453869): Get rid of this hack once we drop Python 2 support and all
 # typeshed references to __builtin__ are gone.
 def RenameBuiltinsPrefixInName(name):
   module, _, basename = name.partition(".")
@@ -699,7 +699,10 @@ class LookupLocalTypes(RemoveTypeParametersFromGenericAny, _ToTypeVisitor):
         except KeyError as e:
           raise SymbolLookupError("Couldn't find %s in %s" % (
               node.name, self.unit.name)) from e
-      resolved_node = self.to_type(item)
+      try:
+        resolved_node = self.to_type(item)
+      except NotImplementedError as e:
+        raise SymbolLookupError("%s is not a type" % item) from e
     elif module_name == self.unit.name:
       # Fully qualified reference to a member of the current module. May contain
       # nested items that need to be recursively resolved.
