@@ -7,6 +7,7 @@
 import atexit
 import os
 import re
+import sys
 import tempfile
 
 
@@ -123,26 +124,30 @@ def list_pytype_files(suffix):
         yield filename[i + len(directory):]
 
 
-# We allow analyzing Python 2 code with a custom interpreter to facilitate use
-# of the type annotations backport.
-CUSTOM_PY2_EXE = None
+# When our open-source tests run on GitHub Actions, we install a Python 3.7
+# interpreter for vm_test.
+CUSTOM_PY37_EXE = "/opt/hostedtoolcache/Python/3.7.11/x64/bin/python3.7"
 
 
 def get_custom_python_exe(python_version):
   """Get the path to a custom python interpreter.
 
-  If the given version is (2, 7), either returns CUSTOM_PY2_EXE if it exists, or
-  extracts it from a par file into /tmp/pytype and returns that.
+  In order to have vm_test target Python 3.7 no matter what the host version is,
+  our open-source tests install a Python 3.7 interpreter when running on GitHub
+  Actions.
 
   Arguments:
-    python_version: the requested version, e.g. (2, 7)
+    python_version: the requested version, e.g. (3, 7)
   Returns:
-    None if the version is not (2, 7) or an error occurs while loading the file.
+    None if:
+      The host version is (3, 7) (we already have a 3.7 interpreter), or
+      the target version is not (3, 7), or
+      an error occurs while loading the file.
     Else: the path to the extracted file.
   """
-  if not CUSTOM_PY2_EXE or python_version != (2, 7):
+  if sys.version_info[:2] == (3, 7) or python_version != (3, 7):
     return None
-  path = os.path.normpath(get_full_path(CUSTOM_PY2_EXE))
+  path = os.path.normpath(get_full_path(CUSTOM_PY37_EXE))
   if os.path.exists(path):
     return path
   try:
